helpers

package
v1.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GinkgoAssertFileContentsEquals

func GinkgoAssertFileContentsEquals(path, expectedContent string)

GinkgoAssertFileContentsEquals check that content of the file match the expected value. prepends vars.FilesystemRoot to the file path to be compatible with GinkgoConfigureFakeFS function

func GinkgoAssertFileDoesNotExist added in v1.6.0

func GinkgoAssertFileDoesNotExist(path string)

GinkgoAssertFileDoesNotExist check that the file exist prepends vars.FilesystemRoot to the file path to be compatible with GinkgoConfigureFakeFS function

func GinkgoConfigureFakeFS

func GinkgoConfigureFakeFS(f *fakefilesystem.FS)

GinkgoConfigureFakeFS configure fake filesystem by setting vars.FilesystemRoot and register Ginkgo DeferCleanup handler to clean the fs when test completed

Types

This section is empty.

Jump to