Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GinkgoAssertFileContentsEquals ¶
func GinkgoAssertFileContentsEquals(path, expectedContent string)
GinkgoAssertFileContentsEquals check that content of the file match the expected value. prepends vars.FilesystemRoot to the file path to be compatible with GinkgoConfigureFakeFS function
func GinkgoAssertFileDoesNotExist ¶ added in v1.6.0
func GinkgoAssertFileDoesNotExist(path string)
GinkgoAssertFileDoesNotExist check that the file exist prepends vars.FilesystemRoot to the file path to be compatible with GinkgoConfigureFakeFS function
func GinkgoConfigureFakeFS ¶
func GinkgoConfigureFakeFS(f *fakefilesystem.FS)
GinkgoConfigureFakeFS configure fake filesystem by setting vars.FilesystemRoot and register Ginkgo DeferCleanup handler to clean the fs when test completed
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.